@@ -30,6 +30,8 @@
 #include <unistd.h>
 #include <dirent.h>
 #include <stdio.h>
+#include <vector>
+#include <string>
 #include <tdelocale.h>
 #include <tqstringlist.h>
 #include <ktextbrowser.h>
@@ -71,9 +73,9 @@ bool canplot;
 
 TQString initial_history;
 
-extern vector<MathFunction*> recent_functions;
-extern vector<Variable*> recent_variables;
-extern vector<Unit*> recent_units;
+extern std::vector<MathFunction*> recent_functions;
+extern std::vector<Variable*> recent_variables;
+extern std::vector<Unit*> recent_units;
 TQValueVector<TQString> recent_functions_pre;
 TQValueVector<TQString> recent_variables_pre;
 TQValueVector<TQString> recent_units_pre;
@@ -84,7 +86,7 @@ TQStringList expression_history;
 
 bool show_keypad, show_history, show_stack;
 
-vector<mode_struct> modes;
+std::vector<mode_struct> modes;
 
 TQValueVector<TQString> inhistory;
 TQValueVector<int> inhistory_type;
@@ -232,7 +234,7 @@ void load_preferences() {
 	load_global_defs = true;
 	fetch_exchange_rates_at_startup = false;
 	first_time = false;
-	string filename = getLocalDir();
+	std::string filename = getLocalDir();
 	DIR *dir = opendir(filename.c_str());
 	if(!dir) {
 		first_qalculate_run = true;
@@ -661,7 +663,7 @@ void load_preferences() {
 void save_preferences(bool mode) {
 
 	FILE *file = NULL;
-	string filename = getLocalDir();
+	std::string filename = getLocalDir();
 	mkdir(filename.c_str(), S_IRWXU);
 	filename += "qalculate-tde.cfg";
 	file = fopen(filename.c_str(), "w+");
