@@ -21,6 +21,8 @@
 
 #include "qalculate_tde_utils.h"
 #include "kqalculate.h"
+#include <vector>
+#include <string>
 #include <tdeversion.h>
 #include <kcursor.h>
 #include <tqstyle.h>
@@ -35,14 +37,14 @@
 #include <tdelocale.h>
 #include <tqsimplerichtext.h>
 
-extern vector<mode_struct> modes;
+extern std::vector<mode_struct> modes;
 
 extern KQalculate *mainWin;
 extern PrintOptions printops;
 extern EvaluationOptions evalops;
 extern bool rpn_mode, rpn_keypad_only;
 extern tree_struct function_cats, unit_cats, variable_cats;
-extern vector<void*> ia_units, ia_variables, ia_functions;
+extern std::vector<void*> ia_units, ia_variables, ia_functions;
 
 class QalculateExpressionEditListBoxItem : public TQListBoxItem {
 
@@ -726,11 +728,11 @@ void set_title(ExpressionItem *item, TQString &title) {
 	}
 }
 
-string sub_suffix(const ExpressionName *ename) {
+std::string sub_suffix(const ExpressionName *ename) {
 	size_t i = ename->name.rfind('_');
-	bool b = i == string::npos || i == ename->name.length() - 1 || i == 0;
+	bool b = i == std::string::npos || i == ename->name.length() - 1 || i == 0;
 	size_t i2 = 1;
-	string str;
+	std::string str;
 	if(b) {
 		if(is_in(NUMBERS, ename->name[ename->name.length() - 1])) {
 			while(ename->name.length() > i2 + 1 && is_in(NUMBERS, ename->name[ename->name.length() - 1 - i2])) {
@@ -749,7 +751,7 @@ string sub_suffix(const ExpressionName *ename) {
 }
 
 TQString makeListName(ExpressionItem *item, TQWidget *w, int *italic_index, bool *rich_text) {
-	string str;
+	std::string str;
 	const ExpressionName *ename, *ename_r;
 	*rich_text = false;
 	bool b = false;
