@@ -20,6 +20,8 @@
 #include "qalculatefunctionsdialog.h"
 #include "qalculate_tde_utils.h"
 #include "qalculateeditfunctiondialog.h"
+#include <vector>
+#include <string>
 #include <kpushbutton.h>
 #include <tqsplitter.h>
 #include <tqvbox.h>
@@ -33,7 +35,7 @@
 #include <kstdguiitem.h>
 
 extern tree_struct function_cats;
-extern vector<void*> ia_functions;
+extern std::vector<void*> ia_functions;
 extern PrintOptions printops;
 
 QalculateFunctionsDialog::QalculateFunctionsDialog(TQWidget *parent, const char *name) : KDialog(parent, name, false) {
@@ -510,7 +512,7 @@ void QalculateFunctionsDialog::categorySelected() {
 		b_inactive = true;
 	}
 	if(!b_all && !no_cat && !b_inactive && selected_category[0] == '/') {
-		string str = selected_category.ascii();
+		std::string str = selected_category.ascii();
 		str.erase(str.begin());
 		for(size_t i = 0; i < CALCULATOR->functions.size(); i++) {
 			if(CALCULATOR->functions[i]->isActive() && CALCULATOR->functions[i]->category().substr(0, selected_category.length() - 1) == str) {
@@ -518,7 +520,7 @@ void QalculateFunctionsDialog::categorySelected() {
 			}
 		}
 	} else {
-		string str = selected_category.ascii();
+		std::string str = selected_category.ascii();
 		for(size_t i = 0; i < CALCULATOR->functions.size(); i++) {
 			if((b_inactive && !CALCULATOR->functions[i]->isActive()) || (CALCULATOR->functions[i]->isActive() && (b_all || (no_cat && CALCULATOR->functions[i]->category().empty()) || (!b_inactive && CALCULATOR->functions[i]->category() == str)))) {
 				addFunctionTreeItem(CALCULATOR->functions[i]);
